<!-- markdownlint-disable -->

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/args.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `args`





---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/args.py#L19"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `main`

```python
main()
```

The main function executes on commands: `python -m earth_osm` and `$ earth_osm `. It parses the command line and executes the appropriate function. 


